<?php
/*
 * Copyright(C) 2003-2005, 2007-2008 op5 AB
 * All rights reserved.
 *
 * If nachos-ui is installed, this file overrides nacoma/export.php
 */

define('SKIP_KOHANA', true);
require('/opt/monitor/op5/ninja/index.php');

require_once('/opt/monitor/op5/nacoma/classes/common_gui.php');
require_once('/opt/monitor/op5/nacoma/include/data.inc.php');
require_once('/opt/monitor/op5/nacoma/include/changelog.inc.php');
require_once('/opt/monitor/op5/nacoma/include/export.inc.php');

if (!isset($console_access)) {
    $page->html_start();
}

$access_messages = checkNachosAccess($page);
if (count($access_messages) > 0) {
    $data = array();
    $data['icon'] = '';
    $data['title'] = "The request to save the configuration was rejected";
    $data['text'] = implode('<br/>', array_unique($access_messages));
    $data['text'] .= "<br /><br /><a href='/monitor/index.php/license' target='_parent'>Click here for more information on how to upgrade your license.</a>";
    renderSavePage($data, $page);
}

$changes = checkForChanges();
$rights = get_rights();
if (!isset($console_access) && !isset($_REQUEST['action'])) {
    if (!count($changes)) {
        if (PHP_SAPI !== 'cli' && !defined('TEST_RUN')) {
            $data = array();

            $data['title'] = "Save configuration";
            $data['text'] = "<p class='saving-p'>Saving will overwrite your current configuration, please review your changes before saving.</p>";
            $data['text'] .= "<h3>Changes</h3>";
            $data['text'] .= "<p class='changesummary'>" . "No changes since last save.";

            renderSavePage($data, $page);
        }
    }

    $data = array();
    $data['icon'] = 'shield-unknown.png';
    $data['title'] = "Save configuration";
    $data['text'] = "<p class='saving-p'>Saving will overwrite your current configuration, please review your changes before saving.</p>";

    $authuser = op5Auth::instance()->get_user();
    $current_user = $authuser->get_username();
    $all_users_with_changes = $changes->get_users();
    $current_user_changes = false;
    $other_users = count($all_users_with_changes);
    if(array_search($current_user, $all_users_with_changes) !== false) {
        $current_user_changes = true;
        $other_users = $other_users - 1;
    }

     if ($other_users > 0) {
        $data['text'] .= "<h3>Other users' changes will be included in the save as well</h3>";
        $data['text'] .= "<p>Be sure to review those changes below before saving.</p>";
    }
    $data['text'] .= "<h3>Changes</h3>";
    $data['text'] .= "<p class='changesummary'>" . $changes->get_summary();
    $data['text'] .= " <a href='#'>More info</a>.</p>";
    $data['text'] .= $changes->get_html_list();

    $data['buttons']['action'] = "local";
    $data['buttons']['user']['id'] = "nachos_save_btn_user";
    $data['buttons']['user']['value'] = (isset($rights['configuration_all']) ? "Save my changes" : "Save");
    $data['buttons']['user']['disabled'] = ($current_user_changes ? "" : "disabled");
    if (isset($rights['configuration_all'])) {
        $data['buttons']['all']['id'] = "nachos_save_btn_full";
        $data['buttons']['all']['value'] = "Save all users' changes";
        $data['buttons']['all']['disabled'] = ($other_users > 0 ? "" : "disabled");
    }

    renderSavePage($data, $page);
}
echo top_bar_nacoma_Model::remove_unsaved_warning();
$page->html_end();


function checkNachosAccess($page)
{
    nacoma_objlock::die_if_locked_hard();

    $access = get_nacoma_access('export');
    if (!in_array(NACOMA_ACCESS_FULL_ACCESS, $access)) {
        deny_access("You're not authorized to save config changes");
    }

    $page->import_if_changes();

    $mayi = op5MayI::instance();
    /* Disable save if license is exceeded */
    $env = array(
        'monitor' => array(
            'monitoring' => array(
                'hosts' => get_num_hosts_configured(),
                'services' => get_num_services_configured()
            )
        )
    );

    $resources = array(
        'monitor.monitoring.hosts',
        'monitor.monitoring.services'
    );

    $access_messages = array();
    foreach ($resources as $resource) {
        if (!$mayi->run($resource . ':create.nacoma', $env, $messages, $perfdata)) {
            $access_messages = array_merge($access_messages, $messages);
        }
    }
    return $access_messages;
}

function checkForChanges()
{
    if (!isset($_REQUEST['action']) || $_REQUEST['action'] === 'full') {
        $changes = new ChangeLog_nacoma_Model(null, null, true);
    } else if (isset($_REQUEST['action']) && $_REQUEST['action'] === 'force') {
        $changes = true;
    } else {
        $changes = new ChangeLog_nacoma_Model(null, null, false);
    }
    return $changes;
}

function renderSavePage($data, $page)
{

    if(!empty($data['icon']) && $data['icon'] != 'shield-unknown.png' ) {
?>
        <img src="images/icons/<?php echo($data['icon']); ?>" alt="" style="display: inline; float: left; margin: 20px 10px 10px 0;" />
<?php
    }
    // Check Nachos Status
    exec('/usr/bin/systemctl is-active --quiet nachos.service', $output, $return_var);
    if ($return_var !== 0){
        echo '<div class="info-notice info-notice-error info-notice-nachos-error">Changes can not be saved since the Configuration Server service (nachos.service) is not active. For troubleshooting, see this' ?> <a href="https://support.itrsgroup.com/hc/en-us/articles/360020056074#sthash.ue0tlktg.dpbs" target="_blank">article</a>.<?php echo '</div>';
    }
?>
    <div class="nachos_save_page" style="margin: 20px 10px 10px 0;">
        <h2><?php echo($data['title']); ?></h2>
        <div><?php echo($data['text']); ?></div>
    </div>
<?php
    if(!empty($data['buttons'])) {
?>
        <form method="post" action="$_SERVER[PHP_SELF]">
            <input type="hidden" name="action" value="<?php echo($data['buttons']['action']); ?>"/>
<?php
            foreach($data['buttons'] as $button) {
                if(!is_array($button) || $button['id'] != 'nachos_save_btn_user' && $button['id'] != 'nachos_save_btn_full') {
                    continue;
                }
?>
                <input type="button" id="<?php echo($button['id']) ?>"
                       name="nachos_save_btn" value="<?php echo($button['value']) ?>"
                       class="nachos_save_btn" <?php echo($button['disabled']) ?> />
<?php
            }
?>
        </form>
<?php
    }
    echo top_bar_nacoma_Model::remove_unsaved_warning();
    $page->html_end();
}
